@@ -5,19 +5,18 @@ use core::convert::AsRef;
 use core::mem::MaybeUninit;
 use core::ops;
 use core::slice;
-use core::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
 
 pub struct History<T, const N: usize> {
-    is_full: AtomicBool,
-    last: AtomicUsize,
+    is_full: bool,
+    last: usize,
     logs: MaybeUninit<[T; N]>,
 }
 impl<T, const N: usize> History<T, N> {
     const CAPACITY: usize = N;
     pub const fn new() -> Self {
         History {
-            is_full: AtomicBool::new(false),
-            last: AtomicUsize::new(0),
+            is_full: false,
+            last: 0,
             logs: MaybeUninit::uninit(),
         }
     }
@@ -27,29 +26,25 @@ impl<T, const N: usize> History<T, N> {
 }
 impl<T: PartialEq, const N: usize> History<T, N> {
     /// 添加记录
-    pub fn insert(&self, value: T) -> bool {
-        if self.contains(&value) {
-            return false;
-        }
-        let last = self.last.load(Ordering::Relaxed);
+    pub fn insert(&mut self, value: T) {
+        let last = self.last;
         if last == Self::CAPACITY - 1 {
-            self.last.store(0, Ordering::Relaxed);
-            self.is_full.store(true, Ordering::Relaxed);
+            self.last = 0;
+            self.is_full = true;
         } else {
-            self.last.store(last + 1, Ordering::Relaxed);
+            self.last = last + 1;
         }
         unsafe { slice::from_raw_parts_mut(self.as_ptr(), Self::CAPACITY)[last] = value };
-        return true;
     }
 }
 impl<T, const N: usize> ops::Deref for History<T, N> {
     type Target = [T];
 
     fn deref(&self) -> &[T] {
-        if self.is_full.load(Ordering::Relaxed) {
+        if self.is_full {
             unsafe { slice::from_raw_parts(self.as_ptr(), Self::CAPACITY) }
         } else {
-            unsafe { slice::from_raw_parts(self.as_ptr(), self.last.load(Ordering::Relaxed)) }
+            unsafe { slice::from_raw_parts(self.as_ptr(), self.last) }
         }
     }
 }
